CN3l
====

.. currentmodule:: pykeen.datasets

.. autoclass:: CN3l
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CN3l.DATASET_NAME
      ~CN3l.FILE_NAMES

   .. rubric:: Attributes Documentation

   .. autoattribute:: DATASET_NAME
   .. autoattribute:: FILE_NAMES
